@@ -22,7 +22,7 @@ import yaml
 from requests.exceptions import HTTPError
 
 from db_contrib_tool.plugin import PluginInterface, Subcommand, SubcommandResult
-from db_contrib_tool.setup_repro_env import config, download, github_conn
+from db_contrib_tool.setup_repro_env import config, download
 from db_contrib_tool.utils import evergreen_conn, is_windows
 
 SUBCOMMAND = "setup-repro-env"
@@ -109,13 +109,11 @@ class SetupReproEnv(Subcommand):
         mv_platform=None,
         edition=None,
         architecture=None,
-        use_latest=None,
         versions=None,
         variant=None,
         install_last_lts=None,
         install_last_continuous=None,
         evergreen_config=None,
-        github_oauth_token=None,
         debug=None,
         ignore_failed_push=False,
         evg_versions_file=None,
@@ -130,7 +128,6 @@ class SetupReproEnv(Subcommand):
         self.inferred_platform = bool(self.platform is None)
         self.architecture = architecture.lower() if architecture else None
         self.variant = variant.lower() if variant else None
-        self.use_latest = use_latest
         self.versions = versions
         self.install_last_lts = install_last_lts
         self.install_last_continuous = install_last_continuous
@@ -142,10 +139,6 @@ class SetupReproEnv(Subcommand):
         self.download_python_venv = download_options.download_python_venv
 
         self.evg_api = evergreen_conn.get_evergreen_api(evergreen_config)
-        # In evergreen github oauth token is stored as `token ******`, so we remove the leading part
-        self.github_oauth_token = (
-            github_oauth_token.replace("token ", "") if github_oauth_token else None
-        )
         with open(config.SETUP_REPRO_ENV_CONFIG) as file_handle:
             raw_yaml = yaml.safe_load(file_handle)
         self.config = config.SetupReproEnvConfig(raw_yaml)
@@ -227,24 +220,19 @@ class SetupReproEnv(Subcommand):
                     if self.inferred_platform
                     else self.platform
                 )
-                urls_info = EvgURLInfo()
-                if self.use_latest:
-                    urls_info = self.get_latest_urls(version)
-                if self.use_latest and not urls_info.urls:
+                urls_info = self.get_latest_urls(version)
+                if not urls_info.urls:
                     LOGGER.warning(
-                        "Latest URLs are not available, falling back"
-                        " to getting the URLs from 'mongodb-mongo-master'"
-                        " project preceding the merge-base commit."
+                        "Latest URLs are not available, falling back to getting the URLs for a specific version."
+                    )
+                    urls_info = self.get_urls(version, self.variant)
+                if not urls_info.urls:
+                    LOGGER.warning(
+                        "Specific version URLs are not available, falling back to getting the URLs from"
+                        " 'mongodb-mongo-master' project preceding the merge-base commit."
                     )
                     merge_base_revision = get_merge_base_commit(version)
                     urls_info = self.get_latest_urls("master", merge_base_revision)
-                if not urls_info.urls:
-                    LOGGER.warning(
-                        "Latest URLs are not available or not requested,"
-                        " falling back to getting the URLs for a specific"
-                        " version."
-                    )
-                    urls_info = self.get_urls(version, self.variant)
                 if not urls_info.urls:
                     raise SetupReproEnvError("URLs are not available for the version.")
 
@@ -257,7 +245,6 @@ class SetupReproEnv(Subcommand):
                 self.download_and_extract(urls, bin_suffix, install_dir)
                 downloaded_versions.append(urls_info.evg_version_id)
             except (
-                github_conn.GithubConnError,
                 evergreen_conn.EvergreenConnError,
                 download.DownloadError,
                 SetupReproEnvError,
@@ -398,20 +385,12 @@ class SetupReproEnv(Subcommand):
         return EvgURLInfo(urls=urls, evg_version_id=actual_version_id)
 
     def get_urls(self, version: str, buildvariant_name: Optional[str] = None) -> EvgURLInfo:
-        """Return multiversion urls for a given version (as binary version or commit hash or evergreen_version_id)."""
+        """Return multiversion urls for a given version (commit hash or evergreen_version_id)."""
         evergreen_projects = evergreen_conn.get_evergreen_projects(self.evg_api)
 
         evg_version = evergreen_conn.get_evergreen_version(
             evergreen_projects, self.evg_api, version
         )
-        if evg_version is None:
-            git_tag, commit_hash = github_conn.get_git_tag_and_commit(
-                self.github_oauth_token, version
-            )
-            LOGGER.info("Found git attributes.", git_tag=git_tag, commit_hash=commit_hash)
-            evg_version = evergreen_conn.get_evergreen_version(
-                evergreen_projects, self.evg_api, commit_hash
-            )
         if evg_version is None:
             return EvgURLInfo()
 
@@ -517,13 +496,32 @@ class _DownloadOptions(object):
 class SetupReproEnvPlugin(PluginInterface):
     """Integration point for setup-repro-env."""
 
+    DEFAULT_INSTALL_DIR = os.path.join(os.getcwd(), "build", "multiversion_bin")
+    DEFAULT_LINK_DIR = os.getcwd()
+    DEFAULT_WITH_ARTIFACTS_INSTALL_DIR = os.path.join(os.getcwd(), "repro_envs")
+    DEFAULT_WITH_ARTIFACTS_LINK_DIR = os.path.join(
+        DEFAULT_WITH_ARTIFACTS_INSTALL_DIR, "multiversion_bin"
+    )
+
+    @classmethod
+    def _update_args(cls, args):
+        """Update command-line arguments."""
+        if not args.versions:
+            args.install_last_lts = True
+            args.install_last_continuous = True
+
+        if args.download_artifacts:
+            args.install_dir = cls.DEFAULT_WITH_ARTIFACTS_INSTALL_DIR
+            args.link_dir = cls.DEFAULT_WITH_ARTIFACTS_LINK_DIR
+
     def parse(self, subcommand, parser, parsed_args, **kwargs):
-        """Parse command-line options."""
+        """Parse command-line arguments."""
         if subcommand != SUBCOMMAND:
             return None
 
         # Shorthand for brevity.
         args = parsed_args
+        self._update_args(args)
 
         download_options = _DownloadOptions(
             db=(not args.skip_binaries),
@@ -538,14 +536,12 @@ class SetupReproEnvPlugin(PluginInterface):
             mv_platform=args.platform,
             edition=args.edition,
             architecture=args.architecture,
-            use_latest=args.use_latest,
             versions=args.versions,
             install_last_lts=args.install_last_lts,
             variant=args.variant,
             install_last_continuous=args.install_last_continuous,
             download_options=download_options,
             evergreen_config=args.evergreen_config,
-            github_oauth_token=args.github_oauth_token,
             ignore_failed_push=(not args.require_push),
             evg_versions_file=args.evg_versions_file,
             debug=args.debug,
@@ -557,16 +553,17 @@ class SetupReproEnvPlugin(PluginInterface):
             "-i",
             "--installDir",
             dest="install_dir",
-            default="build/repro_envs",
-            help="Directory to install the download archive, [default: %(default)s]",
+            default=cls.DEFAULT_INSTALL_DIR,
+            help=f"Directory to install the download archive,"
+            f" [default: %(default)s, if `--downloadArtifacts` is passed: {cls.DEFAULT_WITH_ARTIFACTS_INSTALL_DIR}]",
         )
         parser.add_argument(
             "-l",
             "--linkDir",
             dest="link_dir",
-            default="repro_env",
-            help="Directory to contain links to all binaries for each version "
-            "in the install directory, [default: %(default)s]",
+            default=cls.DEFAULT_LINK_DIR,
+            help=f"Directory to contain links to all binaries for each version in the install directory,"
+            f" [default: %(default)s, if `--downloadArtifacts` is passed: {cls.DEFAULT_WITH_ARTIFACTS_LINK_DIR}]",
         )
         editions = ("base", "enterprise", "targeted")
         parser.add_argument(
@@ -597,26 +594,15 @@ class SetupReproEnvPlugin(PluginInterface):
             "--variant",
             dest="variant",
             default=None,
-            help="Specify a variant to use, "
-            "which supersedes the --platform, --edition and --architecture options.",
-        )
-        parser.add_argument(
-            "-u",
-            "--useLatest",
-            dest="use_latest",
-            action="store_true",
-            help="If specified, the latest version from Evergreen will be downloaded, if it exists, "
-            "for the version specified. For example, if specifying version 4.4 for download, the latest "
-            "version from `mongodb-mongo-v4.4` Evergreen project will be downloaded. Otherwise the latest "
-            "by git tag version will be downloaded.",
+            help="Specify a variant to use, which supersedes the --platform, --edition and"
+            " --architecture options.",
         )
         parser.add_argument(
             "versions",
             nargs="*",
-            help="Accepts binary versions, full git commit hashes, evergreen version ids. "
-            "Binary version examples: 4.0, 4.0.1, 4.0.0-rc0. If 'rc' is included in the version name, "
-            "we'll use the exact rc, otherwise we'll pull the highest non-rc version compatible with the "
-            "version specified.",
+            help="Accepts binary versions, `master`, full git commit hashes, evergreen version ids."
+            " Binary version examples: <major.minor>, 4.2, 4.4, 5.0 etc. If no version is specified"
+            " the last LTS and the last continuous versions will be installed.",
         )
         parser.add_argument(
             "--installLastLTS",
@@ -665,14 +651,6 @@ class SetupReproEnvPlugin(PluginInterface):
             help="Location of evergreen configuration file. If not specified it will look "
             f"for it in the following locations: {evergreen_conn.EVERGREEN_CONFIG_LOCATIONS}",
         )
-        parser.add_argument(
-            "-gt",
-            "--githubOauthToken",
-            dest="github_oauth_token",
-            help="Set the token to increase your rate limit. In most cases it works without auth. "
-            "Otherwise you can pass OAuth token to increase the github API rate limit. See "
-            "https://developer.github.com/v3/#rate-limiting",
-        )
         parser.add_argument(
             "-d",
             "--debug",
